Crate optionally_const_macros

Crate optionally_const_macros 

Derive Macros

FieldlessEnumConstType
Derives the const type for a fieldless enum as well as the implementations of the Const and OptionallyConst traits for the parameterizations of the const type that represent the enum variants.