Derive Macros
- Fieldless
Enum Const Type - Derives the const type for a fieldless enum as well as the implementations
of the
ConstandOptionallyConsttraits for the parameterizations of the const type that represent the enum variants.
Const and OptionallyConst traits for the parameterizations
of the const type that represent the enum variants.